@@ -124,7 +124,12 @@ KBBMainWindow::KBBMainWindow()
 
 	// Menu "Settings"
 	KStandardAction::preferences(this, SLOT(settingsDialog()), actionCollection());
-
+	m_toggleCursorAction = actionCollection()->addAction( QLatin1String( "toggle_cursor" ));
+	m_toggleCursorAction->setText(i18n("Enable highlight under mouse"));
+	m_toggleCursorAction->setCheckable(true);
+	const KConfigGroup group = KSharedConfig::openConfig()->group("default");
+	m_toggleCursorAction->setChecked(group.readEntry<bool>("highlight_enabled", true));
+	connect(m_toggleCursorAction, &QAction::triggered, this, &KBBMainWindow::toggleCursor);
 
 	// Theme manager
 	QString svgzFile = KBBPrefs::theme();
@@ -205,6 +210,9 @@ KBBMainWindow::KBBMainWindow()
 
 	setupGUI();
 
+	if (m_toggleCursorAction->isChecked())
+		toggleCursor();
+
 	// start a new game
 	startGame(false);
 }
@@ -473,6 +481,13 @@ void KBBMainWindow::startTutorial()
 	}
 }
 
+void KBBMainWindow::toggleCursor()
+{
+	m_gameWidget->toggleCursor();
+
+	KConfigGroup group = KSharedConfig::openConfig()->group("default");
+	group.writeEntry<bool>("highlight_enabled", m_toggleCursorAction->isChecked());
+}
 
 
 //
